import React, { createContext, useContext, useRef, useMemo } from 'react';
import IntlMessageFormat from 'intl-messageformat';
import { useRouter } from 'next/router';

var NextIntlContext = /*#__PURE__*/createContext(undefined);

function NextIntlProvider(_ref) {
  var children = _ref.children,
      messages = _ref.messages;
  return React.createElement(NextIntlContext.Provider, {
    value: {
      messages: messages
    }
  }, children);
}

function resolvePath(messages, idPath) {
  var message = messages;
  idPath.split('.').forEach(function (part) {
    var next = message[part];

    if (process.env.NODE_ENV !== "production") {
      if (!part || !next) {
        throw new Error("Could not resolve `" + idPath + "` in `" + JSON.stringify(messages, null, 2) + "`.");
      }
    }

    message = next;
  });
  return message;
}
/**
 * Translates messages from the given path by using the ICU syntax.
 * See https://formatjs.io/docs/core-concepts/icu-syntax.
 *
 * If no path is provided, all available messages are returned.
 *
 * The path can also indicate nesting by using a dot (e.g. `namespace.Component`).
 */


function useTranslations(path) {
  var context = useContext(NextIntlContext);

  var _useRouter = useRouter(),
      locale = _useRouter.locale;

  var cachedFormatsByLocaleRef = useRef({});

  if (!context) {
    if (process.env.NODE_ENV !== "production") {
      throw new Error('No NextIntlContext configured.');
    } else {
      throw new Error();
    }
  }

  var allMessages = context.messages;
  var messages = useMemo(function () {
    return path ? resolvePath(allMessages, path) : allMessages;
  }, [allMessages, path]);

  if (process.env.NODE_ENV !== "production") {
    if (!messages) {
      throw new Error("No messages for component `" + path + "` found.");
    }
  }

  function translate(
  /** Use a dot to indicate a level of nesting (e.g. `namespace.nestedLabel`). */
  idPath, values) {
    var _cachedFormatsByLocal;

    if (!locale) {
      if (process.env.NODE_ENV !== "production") {
        throw new Error('No `locale` received from `useRouter()`');
      } else {
        throw new Error();
      }
    }

    var cachedFormatsByLocale = cachedFormatsByLocaleRef.current;
    var messageFormat;

    if ((_cachedFormatsByLocal = cachedFormatsByLocale[locale]) == null ? void 0 : _cachedFormatsByLocal[idPath]) {
      messageFormat = cachedFormatsByLocale[locale][idPath];
    } else {
      var message = resolvePath(messages, idPath);

      if (typeof message === 'object') {
        if (process.env.NODE_ENV !== "production") {
          throw new Error("Insufficient path specified for `" + idPath + "` in `" + path + "`.");
        } else {
          throw new Error();
        }
      }

      messageFormat = new IntlMessageFormat(message, locale);

      if (!cachedFormatsByLocale[locale]) {
        cachedFormatsByLocale[locale] = {};
      }

      cachedFormatsByLocale[locale][idPath] = messageFormat;
    }

    var formattedMessage = messageFormat.format(values);

    if (process.env.NODE_ENV !== "production") {
      if (formattedMessage === undefined) {
        throw new Error("Unable to format " + path + "." + idPath);
      }
    }

    return formattedMessage;
  }

  return translate;
}

export { NextIntlProvider, useTranslations };
//# sourceMappingURL=next-intl.esm.js.map
